*** Crafting the Law Models
*** Justice System Journal
*** Nelson & Hinkle


use "CTL.dta", clear

*** Data for Figure 2
tab court


*Summary of how Judge Posner uses footnotes and persuasive precedents in his opinions 
tab numFootnotes if fjcid_au == 1922
sum persPrecCited if fjcid_au == 1922, detail
sum persPrecCited, detail


* Table 2: Summary Statistics
sum totDiscussBy totPosTrtBy totNegTrtBy readability numFootnotes persPrecCited totCitedBy logWC bindPrecCited courtBase cfIDExtr age, detail
tab topLawSchool 
tab subExp 
tab priorJud


* Table 3: All Courts Models
* Discussion Model
nbreg totDiscussBy readability numFootnotes persPrecCited topLawSchool subExp priorJud totCitedBy logWC bindPrecCited courtBase cfIDExtr age, cluster(courtYear)
estimates store all
* Positive Treatment Model
nbreg totPosTrtBy readability numFootnotes persPrecCited topLawSchool subExp priorJud totCitedBy logWC bindPrecCited courtBase cfIDExtr age totNegTrtBy, cluster(courtYear)
estimates store pall
* Negative Treatment Model
nbreg totNegTrtBy readability numFootnotes persPrecCited topLawSchool subExp priorJud totCitedBy logWC bindPrecCited courtBase cfIDExtr age totPosTrtBy, cluster(courtYear)
estimates store nall


* Table 4: Factor Analysis Loadings
factor fres fkgl fog smog ari asl , factors(1)
predict read_factor
* readability = read_factor * -1 (so higher numbers indicate more readable text)


* Table 6: Discussion by Institutional Context
nbreg DisByUssct readability numFootnotes persPrecCited topLawSchool subExp priorJud totCitedBy logWC bindPrecCited courtBase cfIDExtr age, cluster(courtYear)
estimates store ussct
nbreg DisBySameCt readability numFootnotes persPrecCited topLawSchool subExp priorJud totCitedBy logWC bindPrecCited courtBase cfIDExtr age, cluster(courtYear)
estimates store same
nbreg DisByHoriz readability numFootnotes persPrecCited topLawSchool subExp priorJud totCitedBy logWC bindPrecCited courtBase cfIDExtr age , cluster(courtYear)
estimates store horiz
nbreg DisByLowerCt readability numFootnotes persPrecCited topLawSchool subExp priorJud totCitedBy logWC bindPrecCited courtBase cfIDExtr age, cluster(courtYear)
estimates store lower


* Table 7: Treatment by Institutional context
nbreg PosTrtBySameCt readability numFootnotes persPrecCited topLawSchool subExp priorJud totCitedBy logWC bindPrecCited courtBase cfIDExtr age NegTrtBySameCt, cluster(courtYear)
estimates store psame
nbreg PosTrtByHoriz readability numFootnotes persPrecCited topLawSchool subExp priorJud totCitedBy logWC bindPrecCited courtBase cfIDExtr age NegTrtByHoriz, cluster(courtYear)
estimates store phoriz
nbreg PosTrtByLowerCt readability numFootnotes persPrecCited topLawSchool subExp priorJud totCitedBy logWC bindPrecCited courtBase cfIDExtr age NegTrtByLowerCt, cluster(courtYear)
estimates store plower
 
nbreg NegTrtBySameCt readability numFootnotes persPrecCited topLawSchool subExp priorJud totCitedBy logWC bindPrecCited courtBase cfIDExtr age PosTrtBySameCt, cluster(courtYear)
estimates store nsame
nbreg NegTrtByHoriz readability numFootnotes persPrecCited topLawSchool subExp priorJud totCitedBy logWC bindPrecCited courtBase cfIDExtr age PosTrtByHoriz, cluster(courtYear)
estimates store nhoriz
nbreg NegTrtByLowerCt readability numFootnotes persPrecCited topLawSchool subExp priorJud totCitedBy logWC bindPrecCited courtBase cfIDExtr age PosTrtByLowerCt, cluster(courtYear)
estimates store nlower


* Figure 4: Predicted Outcomes over Readability and Footnotes
estimates restore all
margins, at(readability=(-5.5(.5)3.5) numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) noesample
estimates restore pall
margins, at(readability=(-5.5(.5)3.5) numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 totNegTrtBy=1)  noesample
estimates restore nall
margins, at(readability=(-5.5(.5)3.5) numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 totPosTrtBy=6)  noesample

estimates restore all
margins, at(readability=0.085 numFootnotes=(0(10)200) persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8)  noesample
estimates restore pall
margins, at(readability=0.085 numFootnotes=(0(10)200) persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 totNegTrtBy=1) 
estimates restore nall
margins, at(readability=0.085 numFootnotes=(0(10)200) persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 totPosTrtBy=6) 


* Figure 5: Predicted Outcomes over Non-Binding Cases Cited and Author Expertise
estimates restore all
margins, at(readability=0.085 numFootnotes=4 persPrecCited=(0(10)140) topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) 
estimates restore pall
margins, at(readability=0.085 numFootnotes=4 persPrecCited=(0(10)140) topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 totNegTrtBy=1) 
estimates restore nall
margins, at(readability=0.085 numFootnotes=4 persPrecCited=(0(10)140) topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 totPosTrtBy=6) 

estimates restore all
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=(0 1) subExp=(0 1) priorJud=(0 1) totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) 
estimates restore pall
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=(0 1) subExp=(0 1) priorJud=(0 1) totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 totNegTrtBy=1) 
estimates restore nall
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=(0 1) subExp=(0 1) priorJud=(0 1) totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 totPosTrtBy=6) 


* Figure 6: Change in Predicted Number of Discussions
estimates restore ussct
margins, at(readability=(-0.57 0.67) numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore ussct
margins, at(readability=0.085 numFootnotes=(1 8) persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore ussct
margins, at(readability=0.085 numFootnotes=4 persPrecCited=(1 10) topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore ussct
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=(0 1) subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore ussct
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=(0 1) priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore ussct
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=(0 1) totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore ussct
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=(17 82) logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore ussct
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=(7.90 8.75) bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore ussct
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=(11 28) courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore ussct
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=(32.98 113.01) cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore ussct
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=(0.417 0.969) age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore ussct
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=(5 11)) post contrast(atcontrast(ar._at)) noesample

estimates restore same
margins, at(readability=(-0.57 0.67) numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore same
margins, at(readability=0.085 numFootnotes=(1 8) persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore same
margins, at(readability=0.085 numFootnotes=4 persPrecCited=(1 10) topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore same
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=(0 1) subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore same
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=(0 1) priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore same
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=(0 1) totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore same
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=(17 82) logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore same
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=(7.90 8.75) bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore same
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=(11 28) courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore same
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=(32.98 113.01) cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore same
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=(0.417 0.969) age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore same
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=(5 11)) post contrast(atcontrast(ar._at)) noesample

estimates restore horiz
margins, at(readability=(-0.57 0.67) numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore horiz
margins, at(readability=0.085 numFootnotes=(1 8) persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore horiz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=(1 10) topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore horiz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=(0 1) subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore horiz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=(0 1) priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore horiz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=(0 1) totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore horiz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=(17 82) logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore horiz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=(7.90 8.75) bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore horiz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=(11 28) courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore horiz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=(32.98 113.01) cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore horiz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=(0.417 0.969) age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore horiz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=(5 11)) post contrast(atcontrast(ar._at)) noesample

estimates restore lower
margins, at(readability=(-0.57 0.67) numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore lower
margins, at(readability=0.085 numFootnotes=(1 8) persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore lower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=(1 10) topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore lower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=(0 1) subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore lower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=(0 1) priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore lower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=(0 1) totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore lower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=(17 82) logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore lower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=(7.90 8.75) bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore lower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=(11 28) courtBase=72.66 cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore lower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=(32.98 113.01) cfIDExtr=.73 age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore lower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=(0.417 0.969) age=8) post contrast(atcontrast(ar._at)) noesample
estimates restore lower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=(5 11)) post contrast(atcontrast(ar._at)) noesample


* Figure 7: Change in Predicted Number of Treatments
estimates restore psame
margins, at(readability=(-0.57 0.67) numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtBySameCt=0) post contrast(atcontrast(ar._at)) noesample
estimates restore psame
margins, at(readability=0.085 numFootnotes=(1 8) persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtBySameCt=0) post contrast(atcontrast(ar._at)) noesample
estimates restore psame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=(1 10) topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtBySameCt=0) post contrast(atcontrast(ar._at)) noesample
estimates restore psame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=(0 1) subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtBySameCt=0) post contrast(atcontrast(ar._at)) noesample
estimates restore psame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=(0 1) priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtBySameCt=0) post contrast(atcontrast(ar._at)) noesample
estimates restore psame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=(0 1) totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtBySameCt=0) post contrast(atcontrast(ar._at)) noesample
estimates restore psame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=(17 82) logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtBySameCt=0) post contrast(atcontrast(ar._at)) noesample
estimates restore psame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=(7.90 8.75) bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtBySameCt=0) post contrast(atcontrast(ar._at)) noesample
estimates restore psame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=(11 28) courtBase=72.66 cfIDExtr=.73 age=8 NegTrtBySameCt=0) post contrast(atcontrast(ar._at)) noesample
estimates restore psame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=(32.98 113.01) cfIDExtr=.73 age=8 NegTrtBySameCt=0) post contrast(atcontrast(ar._at)) noesample
estimates restore psame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=(0.417 0.969) age=8 NegTrtBySameCt=0) post contrast(atcontrast(ar._at)) noesample
estimates restore psame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=(5 11) NegTrtBySameCt=0) post contrast(atcontrast(ar._at)) noesample
estimates restore psame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtBySameCt=(0 1)) post contrast(atcontrast(ar._at)) noesample

estimates restore phoriz
margins, at(readability=(-0.57 0.67) numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore phoriz
margins, at(readability=0.085 numFootnotes=(1 8) persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore phoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=(1 10) topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore phoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=(0 1) subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore phoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=(0 1) priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore phoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=(0 1) totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore phoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=(17 82) logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore phoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=(7.90 8.75) bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore phoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=(11 28) courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore phoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=(32.98 113.01) cfIDExtr=.73 age=8 NegTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore phoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=(0.417 0.969) age=8 NegTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore phoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=(5 11) NegTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore phoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByHoriz=(0 1)) post contrast(atcontrast(ar._at))

estimates restore plower
margins, at(readability=(-0.57 0.67) numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByLowerCt=0) post contrast(atcontrast(ar._at))
estimates restore plower
margins, at(readability=0.085 numFootnotes=(1 8) persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByLowerCt=0) post contrast(atcontrast(ar._at))
estimates restore plower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=(1 10) topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByLowerCt=0) post contrast(atcontrast(ar._at))
estimates restore plower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=(0 1) subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByLowerCt=0) post contrast(atcontrast(ar._at))
estimates restore plower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=(0 1) priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByLowerCt=0) post contrast(atcontrast(ar._at))
estimates restore plower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=(0 1) totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByLowerCt=0) post contrast(atcontrast(ar._at))
estimates restore plower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=(17 82) logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByLowerCt=0) post contrast(atcontrast(ar._at))
estimates restore plower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=(7.90 8.75) bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByLowerCt=0) post contrast(atcontrast(ar._at))
estimates restore plower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=(11 28) courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByLowerCt=0) post contrast(atcontrast(ar._at))
estimates restore plower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=(32.98 113.01) cfIDExtr=.73 age=8 NegTrtByLowerCt=0) post contrast(atcontrast(ar._at))
estimates restore plower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=(0.417 0.969) age=8 NegTrtByLowerCt=0) post contrast(atcontrast(ar._at))
estimates restore plower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=(5 11) NegTrtByLowerCt=0) post contrast(atcontrast(ar._at))
estimates restore plower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 NegTrtByLowerCt=(0 1)) post contrast(atcontrast(ar._at))


estimates restore nsame
margins, at(readability=(-0.57 0.67) numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtBySameCt=1) post contrast(atcontrast(ar._at))
estimates restore nsame
margins, at(readability=0.085 numFootnotes=(1 8) persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtBySameCt=1) post contrast(atcontrast(ar._at))
estimates restore nsame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=(1 10) topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtBySameCt=1) post contrast(atcontrast(ar._at))
estimates restore nsame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=(0 1) subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtBySameCt=1) post contrast(atcontrast(ar._at))
estimates restore nsame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=(0 1) priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtBySameCt=1) post contrast(atcontrast(ar._at))
estimates restore nsame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=(0 1) totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtBySameCt=1) post contrast(atcontrast(ar._at))
estimates restore nsame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=(17 82) logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtBySameCt=1) post contrast(atcontrast(ar._at))
estimates restore nsame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=(7.90 8.75) bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtBySameCt=1) post contrast(atcontrast(ar._at))
estimates restore nsame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=(11 28) courtBase=72.66 cfIDExtr=.73 age=8 PosTrtBySameCt=1) post contrast(atcontrast(ar._at))
estimates restore nsame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=(32.98 113.01) cfIDExtr=.73 age=8 PosTrtBySameCt=1) post contrast(atcontrast(ar._at))
estimates restore nsame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=(0.417 0.969) age=8 PosTrtBySameCt=1) post contrast(atcontrast(ar._at))
estimates restore nsame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=(5 11) PosTrtBySameCt=1) post contrast(atcontrast(ar._at))
estimates restore nsame
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtBySameCt=(0 3)) post contrast(atcontrast(ar._at))

estimates restore nhoriz
margins, at(readability=(-0.57 0.67) numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore nhoriz
margins, at(readability=0.085 numFootnotes=(1 8) persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore nhoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=(1 10) topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore nhoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=(0 1) subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore nhoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=(0 1) priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore nhoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=(0 1) totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore nhoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=(17 82) logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore nhoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=(7.90 8.75) bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore nhoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=(11 28) courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore nhoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=(32.98 113.01) cfIDExtr=.73 age=8 PosTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore nhoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=(0.417 0.969) age=8 PosTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore nhoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=(5 11) PosTrtByHoriz=0) post contrast(atcontrast(ar._at))
estimates restore nhoriz
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByHoriz=(0 1)) post contrast(atcontrast(ar._at))

estimates restore nlower
margins, at(readability=(-0.57 0.67) numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByLowerCt=3) post contrast(atcontrast(ar._at))
estimates restore nlower
margins, at(readability=0.085 numFootnotes=(1 8) persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByLowerCt=3) post contrast(atcontrast(ar._at))
estimates restore nlower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=(1 10) topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByLowerCt=3) post contrast(atcontrast(ar._at))
estimates restore nlower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=(0 1) subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByLowerCt=3) post contrast(atcontrast(ar._at))
estimates restore nlower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=(0 1) priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByLowerCt=3) post contrast(atcontrast(ar._at))
estimates restore nlower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=(0 1) totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByLowerCt=3) post contrast(atcontrast(ar._at))
estimates restore nlower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=(17 82) logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByLowerCt=3) post contrast(atcontrast(ar._at))
estimates restore nlower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=(7.90 8.75) bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByLowerCt=3) post contrast(atcontrast(ar._at))
estimates restore nlower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=(11 28) courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByLowerCt=3) post contrast(atcontrast(ar._at))
estimates restore nlower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=(32.98 113.01) cfIDExtr=.73 age=8 PosTrtByLowerCt=3) post contrast(atcontrast(ar._at))
estimates restore nlower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=(0.417 0.969) age=8 PosTrtByLowerCt=3) post contrast(atcontrast(ar._at))
estimates restore nlower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=(5 11) PosTrtByLowerCt=3) post contrast(atcontrast(ar._at))
estimates restore nlower
margins, at(readability=0.085 numFootnotes=4 persPrecCited=4 topLawSchool=0 subExp=0 priorJud=0 totCitedBy=39 logWC=8.33 bindPrecCited=18 courtBase=72.66 cfIDExtr=.73 age=8 PosTrtByLowerCt=(1 8)) post contrast(atcontrast(ar._at))




 
